# Generated by Django 5.1.6 on 2025-03-12 21:56

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Product",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        db_comment="Timestamp for when the record was created.",
                        help_text="The time when the record was created.",
                        verbose_name="Created at",
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        auto_now=True,
                        db_comment="Timestamp for when the record was last updated.",
                        help_text="The time when the record was last updated.",
                        verbose_name="Updated at",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_comment="Stores the unique name of the product (max 255 characters).",
                        help_text="The unique name identifier for the product.",
                        max_length=255,
                        unique=True,
                        verbose_name="Product Name",
                    ),
                ),
                (
                    "description",
                    models.TextField(
                        blank=True,
                        db_comment="Contains detailed textual description of the product.",
                        help_text="Detailed information about product features and specifications.",
                        verbose_name="Description",
                    ),
                ),
            ],
            options={
                "verbose_name": "Product",
                "verbose_name_plural": "Products",
                "ordering": ["name"],
            },
        ),
        migrations.CreateModel(
            name="Workflow",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        db_comment="Timestamp for when the record was created.",
                        help_text="The time when the record was created.",
                        verbose_name="Created at",
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        auto_now=True,
                        db_comment="Timestamp for when the record was last updated.",
                        help_text="The time when the record was last updated.",
                        verbose_name="Updated at",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_comment="Stores the unique name of the workflow (max 255 characters).",
                        help_text="The unique name identifier for the workflow process.",
                        max_length=255,
                        unique=True,
                        verbose_name="Workflow Name",
                    ),
                ),
                (
                    "description",
                    models.TextField(
                        blank=True,
                        db_comment="Contains detailed textual description of the workflow.",
                        help_text="Detailed explanation of the workflow's purpose and process.",
                        verbose_name="Description",
                    ),
                ),
            ],
            options={
                "verbose_name": "Workflow",
                "verbose_name_plural": "Workflows",
                "ordering": ["name"],
            },
        ),
        migrations.CreateModel(
            name="Step",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        db_comment="Timestamp for when the record was created.",
                        help_text="The time when the record was created.",
                        verbose_name="Created at",
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        auto_now=True,
                        db_comment="Timestamp for when the record was last updated.",
                        help_text="The time when the record was last updated.",
                        verbose_name="Updated at",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_comment="Stores the name of the step within its workflow (max 255 chars).",
                        help_text="The name of the step (must be unique within its workflow).",
                        max_length=255,
                        verbose_name="Step Name",
                    ),
                ),
                (
                    "description",
                    models.TextField(
                        blank=True,
                        db_comment="Contains detailed textual description of the step's process.",
                        help_text="Detailed instructions and requirements for completing the step.",
                        verbose_name="Description",
                    ),
                ),
                (
                    "order",
                    models.PositiveIntegerField(
                        db_comment="Determines the execution sequence order within the workflow.",
                        default=0,
                        help_text="Numerical position in the workflow's execution sequence (starts at 0).",
                        verbose_name="Execution Order",
                    ),
                ),
                (
                    "workflow",
                    models.ForeignKey(
                        db_comment="Foreign key reference to the Workflow model.",
                        help_text="The workflow process that contains this step.",
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="steps",
                        to="product_workflow.workflow",
                        verbose_name="Workflow",
                    ),
                ),
            ],
            options={
                "verbose_name": "Workflow Step",
                "verbose_name_plural": "Workflow Steps",
                "ordering": ["workflow", "order"],
            },
        ),
        migrations.CreateModel(
            name="ProductWorkflow",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        db_comment="Timestamp for when the record was created.",
                        help_text="The time when the record was created.",
                        verbose_name="Created at",
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        auto_now=True,
                        db_comment="Timestamp for when the record was last updated.",
                        help_text="The time when the record was last updated.",
                        verbose_name="Updated at",
                    ),
                ),
                (
                    "product",
                    models.ForeignKey(
                        db_comment="Foreign key reference to the Product model.",
                        help_text="The product associated with this workflow.",
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="workflows",
                        to="product_workflow.product",
                        verbose_name="Product",
                    ),
                ),
                (
                    "first_step",
                    models.ForeignKey(
                        blank=True,
                        db_comment="Foreign key reference to the Step model. Can be null if no step is active.",
                        help_text="The first step in the workflow for this product.",
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="first_step_workflows",
                        to="product_workflow.step",
                        verbose_name="First Step",
                    ),
                ),
                (
                    "last_step",
                    models.ForeignKey(
                        blank=True,
                        db_comment="Foreign key reference to the Step model. Can be null if no step is defined.",
                        help_text="The last step in the workflow for this product.",
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="last_step_workflows",
                        to="product_workflow.step",
                        verbose_name="Last Step",
                    ),
                ),
                (
                    "workflow",
                    models.ForeignKey(
                        db_comment="Foreign key reference to the Workflow model.",
                        help_text="The workflow associated with this product.",
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="product_workflows",
                        to="product_workflow.workflow",
                        verbose_name="Workflow",
                    ),
                ),
            ],
            options={
                "verbose_name": "Product Workflow",
                "verbose_name_plural": "Product Workflows",
            },
        ),
        migrations.CreateModel(
            name="Transition",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        db_comment="Timestamp for when the record was created.",
                        help_text="The time when the record was created.",
                        verbose_name="Created at",
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        auto_now=True,
                        db_comment="Timestamp for when the record was last updated.",
                        help_text="The time when the record was last updated.",
                        verbose_name="Updated at",
                    ),
                ),
                (
                    "condition",
                    models.TextField(
                        blank=True,
                        db_comment="Optional condition or rule for the transition. Can be null if no condition is required.",
                        help_text="An optional condition for this transition (e.g., a rule or logic).",
                        null=True,
                        verbose_name="Condition",
                    ),
                ),
                (
                    "from_step",
                    models.ForeignKey(
                        db_comment="Foreign key reference to the Step model (source step).",
                        help_text="The step this transition starts from.",
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="outgoing_transitions",
                        to="product_workflow.step",
                        verbose_name="From Step",
                    ),
                ),
                (
                    "to_step",
                    models.ForeignKey(
                        db_comment="Foreign key reference to the Step model (destination step).",
                        help_text="The step this transition leads to.",
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="incoming_transitions",
                        to="product_workflow.step",
                        verbose_name="To Step",
                    ),
                ),
                (
                    "workflow",
                    models.ForeignKey(
                        db_comment="Foreign key reference to the Workflow model.",
                        help_text="The workflow this transition belongs to (automatically set from steps).",
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="transitions",
                        to="product_workflow.workflow",
                        verbose_name="Workflow",
                    ),
                ),
            ],
            options={
                "verbose_name": "Transition",
                "verbose_name_plural": "Transitions",
                "constraints": [
                    models.UniqueConstraint(
                        fields=("workflow", "from_step", "to_step"),
                        name="unique_transition_per_workflow",
                        violation_error_message="A transition between the same steps in a workflow must be unique.",
                    )
                ],
            },
        ),
        migrations.AddConstraint(
            model_name="step",
            constraint=models.UniqueConstraint(
                fields=("workflow", "name"),
                name="unique_step_name_per_workflow",
                violation_error_message="Step name must be unique within a workflow",
            ),
        ),
        migrations.AddConstraint(
            model_name="step",
            constraint=models.UniqueConstraint(
                fields=("workflow", "order"),
                name="unique_step_order_per_workflow",
                violation_error_message="Execution order must be unique within a workflow",
            ),
        ),
        migrations.AddConstraint(
            model_name="productworkflow",
            constraint=models.UniqueConstraint(
                fields=("product", "workflow"),
                name="unique_product_workflow",
                violation_error_message="A product can only be associated with a workflow once.",
            ),
        ),
    ]
